#
# from random import random, randint
#
# import math
#
# #
# # for i in range(1, 15):
# #     res = math.pow((1 - .3), i)
# #     nothit = 1 - res
# #     print(f"Odds to hit after {i} shots: {nothit * 100}")
#
#
#
#
# print(1 - math.pow(5.0/6, 3))
#
# '''
# 1 - (5/6)^n = 0.42129629629629617
# '''
#
import pandas as pd



xs = '''INFLUENZA VIRUS VACCINE, NO BRAND NAME (FLUX(SEASONAL))	1991	16	0.00%
INFLUENZA VIRUS VACCINE, NO BRAND NAME (FLUX(SEASONAL))	1992	10	0.00%
INFLUENZA VIRUS VACCINE, NO BRAND NAME (FLUX(SEASONAL))	1993	12	0.00%
INFLUENZA VIRUS VACCINE, NO BRAND NAME (FLUX(SEASONAL))	1994	1	0.00%
INFLUENZA VIRUS VACCINE, NO BRAND NAME (FLUX(SEASONAL))	1996	6	0.00%
INFLUENZA VIRUS VACCINE, NO BRAND NAME (FLUX(SEASONAL))	1998	3	0.00%
INFLUENZA VIRUS VACCINE, NO BRAND NAME (FLUX(SEASONAL))	1999	2	0.00%
INFLUENZA VIRUS VACCINE, NO BRAND NAME (FLUX(SEASONAL))	2001	4	0.00%
INFLUENZA VIRUS VACCINE, NO BRAND NAME (FLUX(SEASONAL))	2002	3	0.00%
INFLUENZA VIRUS VACCINE, NO BRAND NAME (FLUX(SEASONAL))	2003	2	0.00%
INFLUENZA VIRUS VACCINE, NO BRAND NAME (FLUX(SEASONAL))	2004	4	0.00%
INFLUENZA VIRUS VACCINE, NO BRAND NAME (FLUX(SEASONAL))	2005	6	0.00%
INFLUENZA VIRUS VACCINE, NO BRAND NAME (FLUX(SEASONAL))	2006	3	0.00%
INFLUENZA VIRUS VACCINE, NO BRAND NAME (FLUX(SEASONAL))	2007	2	0.00%
INFLUENZA VIRUS VACCINE, NO BRAND NAME (FLUX(SEASONAL))	2008	2	0.00%
INFLUENZA VIRUS VACCINE, NO BRAND NAME (FLUX(SEASONAL))	2009	12	0.00%
INFLUENZA VIRUS VACCINE, NO BRAND NAME (FLUX(SEASONAL))	2010	1	0.00%
INFLUENZA VIRUS VACCINE, NO BRAND NAME (FLUX(SEASONAL))	2011	7	0.00%
INFLUENZA VIRUS VACCINE, NO BRAND NAME (FLUX(SEASONAL))	2012	2	0.00%
INFLUENZA VIRUS VACCINE, NO BRAND NAME (FLUX(SEASONAL))	2013	5	0.00%
INFLUENZA VIRUS VACCINE, NO BRAND NAME (FLUX(SEASONAL))	2014	3	0.00%
INFLUENZA VIRUS VACCINE, NO BRAND NAME (FLUX(SEASONAL))	2015	1	0.00%
INFLUENZA VIRUS VACCINE, NO BRAND NAME (FLUX(SEASONAL))	2016	3	0.00%
INFLUENZA VIRUS VACCINE, NO BRAND NAME (FLUX(SEASONAL))	2017	2	0.00%
INFLUENZA VIRUS VACCINE, NO BRAND NAME (FLUX(SEASONAL))	2019	1	0.00%
INFLUENZA VIRUS VACCINE, NO BRAND NAME (FLUX(SEASONAL))	2020	3	0.00%
INFLUENZA VIRUS VACCINE, NO BRAND NAME (FLUX(SEASONAL))	Unknown Date	175	0.02%
INFLUENZA VIRUS VACCINE, NO BRAND NAME (FLUX(SEASONAL))	No Death	20,020	1.72%'''



xs.split('\n')