import os

path = os.path.dirname(__file__)


red_uri = os.path.join(path, 'red.png')
red_rgb = (235, 0, 0)

green_uri = os.path.join(path, 'green.png')
green_rgb = (120, 73, 21)

pink_uri = os.path.join(path, 'pink.png')
pink_rgb = (255, 101, 222)